Class: Aws::PCS::Types::Cluster
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::Cluster
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
The cluster resource and configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The unique Amazon Resource Name (ARN) of the cluster.
-
#created_at ⇒ Time
The date and time the resource was created.
-
#endpoints ⇒ Array<Types::Endpoint>
The list of endpoints available for interaction with the scheduler.
-
#error_info ⇒ Array<Types::ErrorInfo>
The list of errors that occurred during cluster provisioning.
-
#id ⇒ String
The generated unique ID of the cluster.
-
#modified_at ⇒ Time
The date and time the resource was modified.
-
#name ⇒ String
The name that identifies the cluster.
-
#networking ⇒ Types::Networking
The networking configuration for the cluster’s control plane.
-
#scheduler ⇒ Types::Scheduler
The cluster management and job scheduling software associated with the cluster.
-
#size ⇒ String
The size of the cluster.
-
#slurm_configuration ⇒ Types::ClusterSlurmConfiguration
Additional options related to the Slurm scheduler.
-
#status ⇒ String
The provisioning status of the cluster.
Instance Attribute Details
#arn ⇒ String
The unique Amazon Resource Name (ARN) of the cluster.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-pcs/types.rb', line 217 class Cluster < Struct.new( :name, :id, :arn, :status, :created_at, :modified_at, :scheduler, :size, :slurm_configuration, :networking, :endpoints, :error_info) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the resource was created.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-pcs/types.rb', line 217 class Cluster < Struct.new( :name, :id, :arn, :status, :created_at, :modified_at, :scheduler, :size, :slurm_configuration, :networking, :endpoints, :error_info) SENSITIVE = [] include Aws::Structure end |
#endpoints ⇒ Array<Types::Endpoint>
The list of endpoints available for interaction with the scheduler.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-pcs/types.rb', line 217 class Cluster < Struct.new( :name, :id, :arn, :status, :created_at, :modified_at, :scheduler, :size, :slurm_configuration, :networking, :endpoints, :error_info) SENSITIVE = [] include Aws::Structure end |
#error_info ⇒ Array<Types::ErrorInfo>
The list of errors that occurred during cluster provisioning.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-pcs/types.rb', line 217 class Cluster < Struct.new( :name, :id, :arn, :status, :created_at, :modified_at, :scheduler, :size, :slurm_configuration, :networking, :endpoints, :error_info) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The generated unique ID of the cluster.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-pcs/types.rb', line 217 class Cluster < Struct.new( :name, :id, :arn, :status, :created_at, :modified_at, :scheduler, :size, :slurm_configuration, :networking, :endpoints, :error_info) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time the resource was modified.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-pcs/types.rb', line 217 class Cluster < Struct.new( :name, :id, :arn, :status, :created_at, :modified_at, :scheduler, :size, :slurm_configuration, :networking, :endpoints, :error_info) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name that identifies the cluster.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-pcs/types.rb', line 217 class Cluster < Struct.new( :name, :id, :arn, :status, :created_at, :modified_at, :scheduler, :size, :slurm_configuration, :networking, :endpoints, :error_info) SENSITIVE = [] include Aws::Structure end |
#networking ⇒ Types::Networking
The networking configuration for the cluster’s control plane.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-pcs/types.rb', line 217 class Cluster < Struct.new( :name, :id, :arn, :status, :created_at, :modified_at, :scheduler, :size, :slurm_configuration, :networking, :endpoints, :error_info) SENSITIVE = [] include Aws::Structure end |
#scheduler ⇒ Types::Scheduler
The cluster management and job scheduling software associated with the cluster.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-pcs/types.rb', line 217 class Cluster < Struct.new( :name, :id, :arn, :status, :created_at, :modified_at, :scheduler, :size, :slurm_configuration, :networking, :endpoints, :error_info) SENSITIVE = [] include Aws::Structure end |
#size ⇒ String
The size of the cluster.
-
‘SMALL`: 32 compute nodes and 256 jobs
-
‘MEDIUM`: 512 compute nodes and 8192 jobs
-
‘LARGE`: 2048 compute nodes and 16,384 jobs
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-pcs/types.rb', line 217 class Cluster < Struct.new( :name, :id, :arn, :status, :created_at, :modified_at, :scheduler, :size, :slurm_configuration, :networking, :endpoints, :error_info) SENSITIVE = [] include Aws::Structure end |
#slurm_configuration ⇒ Types::ClusterSlurmConfiguration
Additional options related to the Slurm scheduler.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-pcs/types.rb', line 217 class Cluster < Struct.new( :name, :id, :arn, :status, :created_at, :modified_at, :scheduler, :size, :slurm_configuration, :networking, :endpoints, :error_info) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The provisioning status of the cluster.
<note markdown=“1”> The provisioning status doesn’t indicate the overall health of the cluster.
</note>
The resource enters the ‘SUSPENDING` and `SUSPENDED` states when the scheduler is beyond end of life and we have suspended the cluster. When in these states, you can’t use the cluster. The cluster controller is down and all compute instances are terminated. The resources still count toward your service quotas. You can delete a resource if its status is ‘SUSPENDED`. For more information, see
- Frequently asked questions about Slurm versions in PCS][1
-
in the
*PCS User Guide*.
[1]: docs.aws.amazon.com/pcs/latest/userguide/slurm-versions_faq.html
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/aws-sdk-pcs/types.rb', line 217 class Cluster < Struct.new( :name, :id, :arn, :status, :created_at, :modified_at, :scheduler, :size, :slurm_configuration, :networking, :endpoints, :error_info) SENSITIVE = [] include Aws::Structure end |