Class: Aws::PCS::Types::ClusterSlurmConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

Additional options related to the Slurm scheduler.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_keyTypes::SlurmAuthKey

The shared Slurm key for authentication, also known as the **cluster secret**.

Returns:



136
137
138
139
140
141
142
# File 'lib/aws-sdk-pcs/types.rb', line 136

class ClusterSlurmConfiguration < Struct.new(
  :scale_down_idle_time_in_seconds,
  :slurm_custom_settings,
  :auth_key)
  SENSITIVE = []
  include Aws::Structure
end

#scale_down_idle_time_in_secondsInteger

The time before an idle node is scaled down.

Returns:

  • (Integer)


136
137
138
139
140
141
142
# File 'lib/aws-sdk-pcs/types.rb', line 136

class ClusterSlurmConfiguration < Struct.new(
  :scale_down_idle_time_in_seconds,
  :slurm_custom_settings,
  :auth_key)
  SENSITIVE = []
  include Aws::Structure
end

#slurm_custom_settingsArray<Types::SlurmCustomSetting>

Additional Slurm-specific configuration that directly maps to Slurm settings.

Returns:



136
137
138
139
140
141
142
# File 'lib/aws-sdk-pcs/types.rb', line 136

class ClusterSlurmConfiguration < Struct.new(
  :scale_down_idle_time_in_seconds,
  :slurm_custom_settings,
  :auth_key)
  SENSITIVE = []
  include Aws::Structure
end