Class: Aws::PCS::Types::CreateComputeNodeGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ami_idString

The ID of the Amazon Machine Image (AMI) that PCS uses to launch compute nodes (Amazon EC2 instances). If you don’t provide this value, PCS uses the AMI ID specified in the custom launch template.

Returns:

  • (String)


855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don’t specify a client token, the CLI and SDK automatically generate 1 for you.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_identifierString

The name or ID of the cluster to create a compute node group in.

Returns:

  • (String)


855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#compute_node_group_nameString

A name to identify the cluster. Example: ‘MyCluster`

Returns:

  • (String)


855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#custom_launch_templateTypes::CustomLaunchTemplate

An Amazon EC2 launch template PCS uses to launch compute nodes.



855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#iam_instance_profile_arnString

The Amazon Resource Name (ARN) of the IAM instance profile used to pass an IAM role when launching EC2 instances. The role contained in your instance profile must have the ‘pcs:RegisterComputeNodeGroupInstance` permission and the role name must start with `AWSPCS` or must have the path `/aws-pcs/`. For more information, see [IAM instance profiles for PCS] in the *PCS User Guide*.

[1]: docs.aws.amazon.com/pcs/latest/userguide/security-instance-profiles.html

Returns:

  • (String)


855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_configsArray<Types::InstanceConfig>

A list of EC2 instance configurations that PCS can provision in the compute node group.

Returns:



855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#purchase_optionString

Specifies how EC2 instances are purchased on your behalf. PCS supports On-Demand Instances, Spot Instances, Interruptible Capacity Reservations, On-Demand Capacity Reservations, and Amazon EC2 Capacity Blocks for ML. For more information, see [Amazon EC2 billing and purchasing options] in the *Amazon Elastic Compute Cloud User Guide*. For more information about PCS support for Capacity Blocks, see [Using Amazon EC2 Capacity Blocks for ML with PCS] in the *PCS User Guide*. For more information about PCS support for interruptible capacity reservations, see [Using I-ODCRs with PCS] in the *PCS User Guide*. Choose On-Demand if you plan to use an On-Demand Capacity Reservation (ODCR). For more information, see [Using ODCRs with PCS]. If you don’t provide this option, it defaults to On-Demand.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-purchasing-options.html [2]: docs.aws.amazon.com/pcs/latest/userguide/capacity-blocks.html [3]: docs.aws.amazon.com/pcs/latest/userguide/capacity-reservations-iodcr.html [4]: docs.aws.amazon.com/pcs/latest/userguide/capacity-reservations-odcr.html

Returns:

  • (String)


855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_configurationTypes::ScalingConfigurationRequest

Specifies the boundaries of the compute node group auto scaling.



855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#slurm_configurationTypes::ComputeNodeGroupSlurmConfigurationRequest

Additional options related to the Slurm scheduler.



855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#spot_optionsTypes::SpotOptions

Additional configuration when you specify ‘SPOT` as the `purchaseOption` for the `CreateComputeNodeGroup` API action.

Returns:



855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The list of subnet IDs where the compute node group launches instances. Subnets must be in the same VPC as the cluster.

Returns:

  • (Array<String>)


855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

1 or more tags added to the resource. Each tag consists of a tag key and tag value. The tag value is optional and can be an empty string.

Returns:

  • (Hash<String,String>)


855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
# File 'lib/aws-sdk-pcs/types.rb', line 855

class CreateComputeNodeGroupRequest < Struct.new(
  :cluster_identifier,
  :compute_node_group_name,
  :ami_id,
  :subnet_ids,
  :purchase_option,
  :custom_launch_template,
  :iam_instance_profile_arn,
  :scaling_configuration,
  :instance_configs,
  :spot_options,
  :slurm_configuration,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end