Class: Aws::PCS::Types::CreateQueueRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::CreateQueueRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cluster_identifier ⇒ String
The name or ID of the cluster for which to create a queue.
-
#compute_node_group_configurations ⇒ Array<Types::ComputeNodeGroupConfiguration>
The list of compute node group configurations to associate with the queue.
-
#queue_name ⇒ String
A name to identify the queue.
-
#tags ⇒ Hash<String,String>
1 or more tags added to the resource.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don’t specify a client token, the CLI and SDK automatically generate 1 for you.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
691 692 693 694 695 696 697 698 699 |
# File 'lib/aws-sdk-pcs/types.rb', line 691 class CreateQueueRequest < Struct.new( :cluster_identifier, :queue_name, :compute_node_group_configurations, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#cluster_identifier ⇒ String
The name or ID of the cluster for which to create a queue.
691 692 693 694 695 696 697 698 699 |
# File 'lib/aws-sdk-pcs/types.rb', line 691 class CreateQueueRequest < Struct.new( :cluster_identifier, :queue_name, :compute_node_group_configurations, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#compute_node_group_configurations ⇒ Array<Types::ComputeNodeGroupConfiguration>
The list of compute node group configurations to associate with the queue. Queues assign jobs to associated compute node groups.
691 692 693 694 695 696 697 698 699 |
# File 'lib/aws-sdk-pcs/types.rb', line 691 class CreateQueueRequest < Struct.new( :cluster_identifier, :queue_name, :compute_node_group_configurations, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#queue_name ⇒ String
A name to identify the queue.
691 692 693 694 695 696 697 698 699 |
# File 'lib/aws-sdk-pcs/types.rb', line 691 class CreateQueueRequest < Struct.new( :cluster_identifier, :queue_name, :compute_node_group_configurations, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
1 or more tags added to the resource. Each tag consists of a tag key and tag value. The tag value is optional and can be an empty string.
691 692 693 694 695 696 697 698 699 |
# File 'lib/aws-sdk-pcs/types.rb', line 691 class CreateQueueRequest < Struct.new( :cluster_identifier, :queue_name, :compute_node_group_configurations, :client_token, :tags) SENSITIVE = [] include Aws::Structure end |