Class: Aws::PCS::Types::DeleteQueueRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don't specify a client token, the CLI and SDK automatically generate 1 for you.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1089
1090
1091
1092
1093
1094
1095
# File 'lib/aws-sdk-pcs/types.rb', line 1089

class DeleteQueueRequest < Struct.new(
  :cluster_identifier,
  :queue_identifier,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_identifierString

The name or ID of the cluster of the queue.

Returns:

  • (String)


1089
1090
1091
1092
1093
1094
1095
# File 'lib/aws-sdk-pcs/types.rb', line 1089

class DeleteQueueRequest < Struct.new(
  :cluster_identifier,
  :queue_identifier,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#queue_identifierString

The name or ID of the queue to delete.

Returns:

  • (String)


1089
1090
1091
1092
1093
1094
1095
# File 'lib/aws-sdk-pcs/types.rb', line 1089

class DeleteQueueRequest < Struct.new(
  :cluster_identifier,
  :queue_identifier,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end