Class: Aws::PCS::Types::ListClustersResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#clusters ⇒ Array<Types::ClusterSummary>

The list of clusters.

Returns:



1371
1372
1373
1374
1375
1376
# File 'lib/aws-sdk-pcs/types.rb', line 1371

class ListClustersResponse < Struct.new(
  :clusters,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The value of nextToken is a unique pagination token for each page of results returned. If nextToken is returned, there are more results available. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token returns an HTTP 400 InvalidToken error.

Returns:

  • (String)


1371
1372
1373
1374
1375
1376
# File 'lib/aws-sdk-pcs/types.rb', line 1371

class ListClustersResponse < Struct.new(
  :clusters,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end