Class: Aws::PCS::Types::ListComputeNodeGroupsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifier ⇒ String

The name or ID of the cluster to list compute node groups for.

Returns:

  • (String)


1400
1401
1402
1403
1404
1405
1406
# File 'lib/aws-sdk-pcs/types.rb', line 1400

class ListComputeNodeGroupsRequest < Struct.new(
  :cluster_identifier,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results that are returned per call. You can use nextToken to obtain further pages of results. The default is 10 results, and the maximum allowed page size is 100 results. A value of 0 uses the default.

Returns:

  • (Integer)


1400
1401
1402
1403
1404
1405
1406
# File 'lib/aws-sdk-pcs/types.rb', line 1400

class ListComputeNodeGroupsRequest < Struct.new(
  :cluster_identifier,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The value of nextToken is a unique pagination token for each page of results returned. If nextToken is returned, there are more results available. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token returns an HTTP 400 InvalidToken error.

Returns:

  • (String)


1400
1401
1402
1403
1404
1405
1406
# File 'lib/aws-sdk-pcs/types.rb', line 1400

class ListComputeNodeGroupsRequest < Struct.new(
  :cluster_identifier,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end