Class: Aws::PCS::Types::ListComputeNodeGroupsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::ListComputeNodeGroupsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compute_node_groups ⇒ Array<Types::ComputeNodeGroupSummary>
The list of compute node groups for the cluster.
-
#next_token ⇒ String
The value of
nextTokenis a unique pagination token for each page of results returned.
Instance Attribute Details
#compute_node_groups ⇒ Array<Types::ComputeNodeGroupSummary>
The list of compute node groups for the cluster.
1423 1424 1425 1426 1427 1428 |
# File 'lib/aws-sdk-pcs/types.rb', line 1423 class ListComputeNodeGroupsResponse < Struct.new( :compute_node_groups, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The value of nextToken is a unique pagination token for each page
of results returned. If nextToken is returned, there are more
results available. Make the call again using the returned token to
retrieve the next page. Keep all other arguments unchanged. Each
pagination token expires after 24 hours. Using an expired pagination
token returns an HTTP 400 InvalidToken error.
1423 1424 1425 1426 1427 1428 |
# File 'lib/aws-sdk-pcs/types.rb', line 1423 class ListComputeNodeGroupsResponse < Struct.new( :compute_node_groups, :next_token) SENSITIVE = [] include Aws::Structure end |