Class: Aws::PCS::Types::ListQueuesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifier ⇒ String

The name or ID of the cluster to list queues for.

Returns:

  • (String)


1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-pcs/types.rb', line 1452

class ListQueuesRequest < Struct.new(
  :cluster_identifier,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results that are returned per call. You can use nextToken to obtain further pages of results. The default is 10 results, and the maximum allowed page size is 100 results. A value of 0 uses the default.

Returns:

  • (Integer)


1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-pcs/types.rb', line 1452

class ListQueuesRequest < Struct.new(
  :cluster_identifier,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The value of nextToken is a unique pagination token for each page of results returned. If nextToken is returned, there are more results available. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token returns an HTTP 400 InvalidToken error.

Returns:

  • (String)


1452
1453
1454
1455
1456
1457
1458
# File 'lib/aws-sdk-pcs/types.rb', line 1452

class ListQueuesRequest < Struct.new(
  :cluster_identifier,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end