Class: Aws::PCS::Types::NetworkingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

The networking configuration for the cluster’s control plane.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#security_group_idsArray<String>

A list of security group IDs associated with the Elastic Network Interface (ENI) created in subnets.

Returns:

  • (Array<String>)


1257
1258
1259
1260
1261
1262
# File 'lib/aws-sdk-pcs/types.rb', line 1257

class NetworkingRequest < Struct.new(
  :subnet_ids,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The list of subnet IDs where Amazon Web Services PCS creates an Elastic Network Interface (ENI) to enable communication between managed controllers and Amazon Web Services PCS resources. Subnet IDs have the form subnet-0123456789abcdef0.

Subnets can’t be in Outposts, Wavelength or an Amazon Web Services Local Zone.

<note markdown=“1”> Amazon Web Services PCS currently supports only 1 subnet in this list.

</note>

Returns:

  • (Array<String>)


1257
1258
1259
1260
1261
1262
# File 'lib/aws-sdk-pcs/types.rb', line 1257

class NetworkingRequest < Struct.new(
  :subnet_ids,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end