Class: Aws::PCS::Types::NodeLifecycleScript

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

A script to run during a compute node lifecycle stage.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#argumentsArray<String>

The command-line arguments to pass to the script. You can specify up to 20 arguments, and each argument can be up to 256 characters long.

Returns:

  • (Array<String>)


1678
1679
1680
1681
1682
1683
1684
1685
1686
# File 'lib/aws-sdk-pcs/types.rb', line 1678

class NodeLifecycleScript < Struct.new(
  :name,
  :script_source,
  :arguments,
  :on_error,
  :execution_policy)
  SENSITIVE = []
  include Aws::Structure
end

#execution_policyString

The policy that determines when the script runs. The default value is FIRST_BOOT_ONLY. Valid values:

  • FIRST_BOOT_ONLY – Runs the script only the first time the compute node boots.

  • EVERY_BOOT – Runs the script every time the compute node boots, including reboots.

Returns:

  • (String)


1678
1679
1680
1681
1682
1683
1684
1685
1686
# File 'lib/aws-sdk-pcs/types.rb', line 1678

class NodeLifecycleScript < Struct.new(
  :name,
  :script_source,
  :arguments,
  :on_error,
  :execution_policy)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A unique name for the script. The name can be up to 64 characters long. Valid characters are letters, numbers, spaces, underscores (_), and hyphens (-). The first character must be a letter or a number.

Returns:

  • (String)


1678
1679
1680
1681
1682
1683
1684
1685
1686
# File 'lib/aws-sdk-pcs/types.rb', line 1678

class NodeLifecycleScript < Struct.new(
  :name,
  :script_source,
  :arguments,
  :on_error,
  :execution_policy)
  SENSITIVE = []
  include Aws::Structure
end

#on_errorString

The behavior when the script fails. The default value is TERMINATE. Valid values:

  • TERMINATE – Terminates the compute node.

  • STOP_SEQUENCE – Stops running subsequent scripts in the sequence but doesn't terminate the compute node.

  • CONTINUE – Ignores the error and continues running the next script.

Returns:

  • (String)


1678
1679
1680
1681
1682
1683
1684
1685
1686
# File 'lib/aws-sdk-pcs/types.rb', line 1678

class NodeLifecycleScript < Struct.new(
  :name,
  :script_source,
  :arguments,
  :on_error,
  :execution_policy)
  SENSITIVE = []
  include Aws::Structure
end

#script_sourceTypes::ScriptSource

The source location and integrity information for the script.

Returns:



1678
1679
1680
1681
1682
1683
1684
1685
1686
# File 'lib/aws-sdk-pcs/types.rb', line 1678

class NodeLifecycleScript < Struct.new(
  :name,
  :script_source,
  :arguments,
  :on_error,
  :execution_policy)
  SENSITIVE = []
  include Aws::Structure
end