Class: Aws::PCS::Types::QueueSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

The object returned by the ListQueues API action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The unique Amazon Resource Name (ARN) of the queue.

Returns:

  • (String)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-pcs/types.rb', line 1891

class QueueSummary < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_id ⇒ String

The ID of the cluster of the queue.

Returns:

  • (String)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-pcs/types.rb', line 1891

class QueueSummary < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The date and time the resource was created.

Returns:

  • (Time)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-pcs/types.rb', line 1891

class QueueSummary < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The generated unique ID of the queue.

Returns:

  • (String)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-pcs/types.rb', line 1891

class QueueSummary < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#modified_at ⇒ Time

The date and time the resource was modified.

Returns:

  • (Time)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-pcs/types.rb', line 1891

class QueueSummary < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name that identifies the queue.

Returns:

  • (String)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-pcs/types.rb', line 1891

class QueueSummary < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The provisioning status of the queue.

The provisioning status doesn't indicate the overall health of the queue.

The resource enters the SUSPENDING and SUSPENDED states when the scheduler is beyond end of life and we have suspended the cluster. When in these states, you can't use the cluster. The cluster controller is down and all compute instances are terminated. The resources still count toward your service quotas. You can delete a resource if its status is SUSPENDED. For more information, see Frequently asked questions about Slurm versions in PCS in the PCS User Guide.

Returns:

  • (String)


1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-pcs/types.rb', line 1891

class QueueSummary < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status)
  SENSITIVE = []
  include Aws::Structure
end