Class: Aws::PCS::Types::Scheduler

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

The cluster management and job scheduling software associated with the cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

The software PCS uses to manage cluster scaling and job scheduling.

Returns:

  • (String)


2043
2044
2045
2046
2047
2048
# File 'lib/aws-sdk-pcs/types.rb', line 2043

class Scheduler < Struct.new(
  :type,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the specified scheduling software that PCS uses to manage cluster scaling and job scheduling. You can update this version using the UpdateCluster API action. For more information, see Updating the scheduler version on a cluster and Slurm versions in PCS in the PCS User Guide.

Valid Values: 23.11 | 24.05 | 24.11 | 25.05 | 25.11

Returns:

  • (String)


2043
2044
2045
2046
2047
2048
# File 'lib/aws-sdk-pcs/types.rb', line 2043

class Scheduler < Struct.new(
  :type,
  :version)
  SENSITIVE = []
  include Aws::Structure
end