Class: Aws::PCS::Types::SchedulerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

The cluster management and job scheduling software associated with the cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#typeString

The software PCS uses to manage cluster scaling and job scheduling.

Returns:

  • (String)


1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-pcs/types.rb', line 1896

class SchedulerRequest < Struct.new(
  :type,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the specified scheduling software that PCS uses to manage cluster scaling and job scheduling. For more information, see Slurm versions in PCS in the PCS User Guide.

Valid Values: 24.11 | 25.05 | 25.11

Returns:

  • (String)


1896
1897
1898
1899
1900
1901
# File 'lib/aws-sdk-pcs/types.rb', line 1896

class SchedulerRequest < Struct.new(
  :type,
  :version)
  SENSITIVE = []
  include Aws::Structure
end