Class: Aws::PCS::Types::ServiceQuotaExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::ServiceQuotaExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
You exceeded your service quota. Service quotas, also referred to as limits, are the maximum number of service resources or operations for your Amazon Web Services account. To learn how to increase your service quota, see Requesting a quota increase in the Service Quotas User Guide
Examples
-
The max number of clusters or queues has been reached for the account.
-
The max number of compute node groups has been reached for the associated cluster.
-
The total of
maxInstancesacross all compute node groups has been reached for associated cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#quota_code ⇒ String
The quota code of the service quota that was exceeded.
-
#resource_id ⇒ String
The unique identifier of the resource that caused the quota to be exceeded.
-
#resource_type ⇒ String
The type or category of the resource that caused the quota to be exceeded.
-
#service_code ⇒ String
The service code associated with the quota that was exceeded.
Instance Attribute Details
#message ⇒ String
2152 2153 2154 2155 2156 2157 2158 2159 2160 |
# File 'lib/aws-sdk-pcs/types.rb', line 2152 class ServiceQuotaExceededException < Struct.new( :message, :service_code, :resource_id, :resource_type, :quota_code) SENSITIVE = [] include Aws::Structure end |
#quota_code ⇒ String
The quota code of the service quota that was exceeded.
2152 2153 2154 2155 2156 2157 2158 2159 2160 |
# File 'lib/aws-sdk-pcs/types.rb', line 2152 class ServiceQuotaExceededException < Struct.new( :message, :service_code, :resource_id, :resource_type, :quota_code) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
The unique identifier of the resource that caused the quota to be exceeded.
2152 2153 2154 2155 2156 2157 2158 2159 2160 |
# File 'lib/aws-sdk-pcs/types.rb', line 2152 class ServiceQuotaExceededException < Struct.new( :message, :service_code, :resource_id, :resource_type, :quota_code) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type or category of the resource that caused the quota to be exceeded.
2152 2153 2154 2155 2156 2157 2158 2159 2160 |
# File 'lib/aws-sdk-pcs/types.rb', line 2152 class ServiceQuotaExceededException < Struct.new( :message, :service_code, :resource_id, :resource_type, :quota_code) SENSITIVE = [] include Aws::Structure end |
#service_code ⇒ String
The service code associated with the quota that was exceeded.
2152 2153 2154 2155 2156 2157 2158 2159 2160 |
# File 'lib/aws-sdk-pcs/types.rb', line 2152 class ServiceQuotaExceededException < Struct.new( :message, :service_code, :resource_id, :resource_type, :quota_code) SENSITIVE = [] include Aws::Structure end |