Class: Aws::PCS::Types::SlurmCustomSetting

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

Additional settings that directly map to Slurm settings.

PCS supports a subset of Slurm settings. For more information, see Configuring custom Slurm settings in PCS in the PCS User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#parameter_nameString

PCS supports custom Slurm settings for clusters, compute node groups, and queues. For more information, see Configuring custom Slurm settings in PCS in the PCS User Guide.

Returns:

  • (String)


2002
2003
2004
2005
2006
2007
# File 'lib/aws-sdk-pcs/types.rb', line 2002

class SlurmCustomSetting < Struct.new(
  :parameter_name,
  :parameter_value)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_valueString

The values for the configured Slurm settings.

Returns:

  • (String)


2002
2003
2004
2005
2006
2007
# File 'lib/aws-sdk-pcs/types.rb', line 2002

class SlurmCustomSetting < Struct.new(
  :parameter_name,
  :parameter_value)
  SENSITIVE = []
  include Aws::Structure
end