Class: Aws::PCS::Types::UpdateAccountingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::UpdateAccountingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
The accounting configuration includes configurable settings for Slurm accounting.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_purge_time_in_days ⇒ Integer
The default value for all purge settings for
slurmdbd.conf. -
#mode ⇒ String
The default value for
modeisNONE.
Instance Attribute Details
#default_purge_time_in_days ⇒ Integer
The default value for all purge settings for slurmdbd.conf. For
more information, see the slurmdbd.conf documentation at
SchedMD.
The default value for defaultPurgeTimeInDays is -1.
A value of -1 means there is no purge time and records persist as
long as the cluster exists.
0 isn't a valid value.
2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-pcs/types.rb', line 2191 class UpdateAccountingRequest < Struct.new( :default_purge_time_in_days, :mode) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The default value for mode is NONE. A value of STANDARD means
Slurm accounting is enabled.
2191 2192 2193 2194 2195 2196 |
# File 'lib/aws-sdk-pcs/types.rb', line 2191 class UpdateAccountingRequest < Struct.new( :default_purge_time_in_days, :mode) SENSITIVE = [] include Aws::Structure end |