Class: Aws::PCS::Types::UpdateQueueRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don't specify a client token, the CLI and SDK automatically generate 1 for you.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2709
2710
2711
2712
2713
2714
2715
2716
2717
# File 'lib/aws-sdk-pcs/types.rb', line 2709

class UpdateQueueRequest < Struct.new(
  :cluster_identifier,
  :queue_identifier,
  :compute_node_group_configurations,
  :slurm_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_identifierString

The name or ID of the cluster of the queue.

Returns:

  • (String)


2709
2710
2711
2712
2713
2714
2715
2716
2717
# File 'lib/aws-sdk-pcs/types.rb', line 2709

class UpdateQueueRequest < Struct.new(
  :cluster_identifier,
  :queue_identifier,
  :compute_node_group_configurations,
  :slurm_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#compute_node_group_configurationsArray<Types::ComputeNodeGroupConfiguration>

The list of compute node group configurations to associate with the queue. Queues assign jobs to associated compute node groups.



2709
2710
2711
2712
2713
2714
2715
2716
2717
# File 'lib/aws-sdk-pcs/types.rb', line 2709

class UpdateQueueRequest < Struct.new(
  :cluster_identifier,
  :queue_identifier,
  :compute_node_group_configurations,
  :slurm_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#queue_identifierString

The name or ID of the queue.

Returns:

  • (String)


2709
2710
2711
2712
2713
2714
2715
2716
2717
# File 'lib/aws-sdk-pcs/types.rb', line 2709

class UpdateQueueRequest < Struct.new(
  :cluster_identifier,
  :queue_identifier,
  :compute_node_group_configurations,
  :slurm_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#slurm_configurationTypes::UpdateQueueSlurmConfigurationRequest

Additional options related to the Slurm scheduler.



2709
2710
2711
2712
2713
2714
2715
2716
2717
# File 'lib/aws-sdk-pcs/types.rb', line 2709

class UpdateQueueRequest < Struct.new(
  :cluster_identifier,
  :queue_identifier,
  :compute_node_group_configurations,
  :slurm_configuration,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end