Class: Aws::PCS::Types::UpdateSchedulerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

The scheduler configuration for updating a cluster. Use this to specify the Slurm version to upgrade to.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#versionString

The Slurm version to upgrade the cluster to. You can only upgrade to a newer version. For more information about supported versions and upgrade paths, see Upgrading the Slurm version on a cluster in the PCS User Guide.

Valid Values: 24.05 | 24.11 | 25.05 | 25.11

Returns:

  • (String)


2524
2525
2526
2527
2528
# File 'lib/aws-sdk-pcs/types.rb', line 2524

class UpdateSchedulerRequest < Struct.new(
  :version)
  SENSITIVE = []
  include Aws::Structure
end