Class: Aws::PCS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PCS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-pcs/client.rb,
sig/client.rbs
Overview
An API client for PCS. To construct a client, you need to configure a :region and :credentials.
client = Aws::PCS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateClusterResponseSuccess, _CreateComputeNodeGroupResponseSuccess, _CreateQueueResponseSuccess, _DeleteClusterResponseSuccess, _DeleteComputeNodeGroupResponseSuccess, _DeleteQueueResponseSuccess, _GetClusterResponseSuccess, _GetComputeNodeGroupResponseSuccess, _GetQueueResponseSuccess, _ListClustersResponseSuccess, _ListComputeNodeGroupsResponseSuccess, _ListQueuesResponseSuccess, _ListTagsForResourceResponseSuccess, _RegisterComputeNodeGroupInstanceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateClusterResponseSuccess, _UpdateComputeNodeGroupResponseSuccess, _UpdateQueueResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a cluster in your account.
-
#create_compute_node_group(params = {}) ⇒ Types::CreateComputeNodeGroupResponse
Creates a managed set of compute nodes.
-
#create_queue(params = {}) ⇒ Types::CreateQueueResponse
Creates a job queue.
-
#delete_cluster(params = {}) ⇒ Struct
Deletes a cluster and all its linked resources.
-
#delete_compute_node_group(params = {}) ⇒ Struct
Deletes a compute node group.
-
#delete_queue(params = {}) ⇒ Struct
Deletes a job queue.
-
#get_cluster(params = {}) ⇒ Types::GetClusterResponse
Returns detailed information about a running cluster in your account.
-
#get_compute_node_group(params = {}) ⇒ Types::GetComputeNodeGroupResponse
Returns detailed information about a compute node group.
-
#get_queue(params = {}) ⇒ Types::GetQueueResponse
Returns detailed information about a queue.
-
#list_clusters(params = {}) ⇒ Types::ListClustersResponse
Returns a list of running clusters in your account.
-
#list_compute_node_groups(params = {}) ⇒ Types::ListComputeNodeGroupsResponse
Returns a list of all compute node groups associated with a cluster.
-
#list_queues(params = {}) ⇒ Types::ListQueuesResponse
Returns a list of all queues associated with a cluster.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of all tags on an PCS resource.
-
#register_compute_node_group_instance(params = {}) ⇒ Types::RegisterComputeNodeGroupInstanceResponse
This API action isn't intended for you to use.
-
#tag_resource(params = {}) ⇒ Struct
Adds or edits tags on an PCS resource.
-
#untag_resource(params = {}) ⇒ Struct
Deletes tags from an PCS resource.
-
#update_cluster(params = {}) ⇒ Types::UpdateClusterResponse
Updates a cluster configuration.
-
#update_compute_node_group(params = {}) ⇒ Types::UpdateComputeNodeGroupResponse
Updates a compute node group.
-
#update_queue(params = {}) ⇒ Types::UpdateQueueResponse
Updates the compute node group configuration of a queue.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-pcs/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1899 1900 1901 |
# File 'lib/aws-sdk-pcs/client.rb', line 1899 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1902 1903 1904 |
# File 'lib/aws-sdk-pcs/client.rb', line 1902 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 |
# File 'lib/aws-sdk-pcs/client.rb', line 1872 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PCS') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-pcs' context[:gem_version] = '1.50.0' Seahorse::Client::Request.new(handlers, context) end |
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a cluster in your account. PCS creates the cluster controller in a service-owned account. The cluster controller communicates with the cluster resources in your account. The subnets and security groups for the cluster must already exist before you use this API action.
Creating state until it is ready to use. There can only be 1 cluster
in a Creating state per Amazon Web Services Region per Amazon Web
Services account. CreateCluster fails with a
ServiceQuotaExceededException if there is already a cluster in a
Creating state.
87 |
# File 'sig/client.rbs', line 87
def create_cluster: (
|
#create_compute_node_group(params = {}) ⇒ Types::CreateComputeNodeGroupResponse
Creates a managed set of compute nodes. You associate a compute node group with a cluster through 1 or more PCS queues or as part of the login fleet. A compute node group includes the definition of the compute properties and lifecycle management. PCS uses the information you provide to this API action to launch compute nodes in your account. You can only specify subnets in the same Amazon VPC as your cluster. You receive billing charges for the compute nodes that PCS launches in your account. You must already have a launch template before you call this API. For more information, see Launch an instance from a launch template in the Amazon Elastic Compute Cloud User Guide for Linux Instances.
137 |
# File 'sig/client.rbs', line 137
def create_compute_node_group: (
|
#create_queue(params = {}) ⇒ Types::CreateQueueResponse
Creates a job queue. You must associate 1 or more compute node groups with the queue. You can associate 1 compute node group with multiple queues.
179 |
# File 'sig/client.rbs', line 179
def create_queue: (
|
#delete_cluster(params = {}) ⇒ Struct
Deletes a cluster and all its linked resources. You must delete all queues and compute node groups associated with the cluster before you can delete the cluster.
204 |
# File 'sig/client.rbs', line 204
def delete_cluster: (
|
#delete_compute_node_group(params = {}) ⇒ Struct
Deletes a compute node group. You must delete all queues associated with the compute node group first.
214 |
# File 'sig/client.rbs', line 214
def delete_compute_node_group: (
|
#delete_queue(params = {}) ⇒ Struct
Deletes a job queue. If the compute node group associated with this queue isn't associated with any other queues, PCS terminates all the compute nodes for this queue.
225 |
# File 'sig/client.rbs', line 225
def delete_queue: (
|
#get_cluster(params = {}) ⇒ Types::GetClusterResponse
Returns detailed information about a running cluster in your account. This API action provides networking information, endpoint information for communication with the scheduler, and provisioning status.
237 |
# File 'sig/client.rbs', line 237
def get_cluster: (
|
#get_compute_node_group(params = {}) ⇒ Types::GetComputeNodeGroupResponse
Returns detailed information about a compute node group. This API action provides networking information, EC2 instance type, compute node group status, and scheduler (such as Slurm) configuration.
247 |
# File 'sig/client.rbs', line 247
def get_compute_node_group: (
|
#get_queue(params = {}) ⇒ Types::GetQueueResponse
Returns detailed information about a queue. The information includes the compute node groups that the queue uses to schedule jobs.
258 |
# File 'sig/client.rbs', line 258
def get_queue: (
|
#list_clusters(params = {}) ⇒ Types::ListClustersResponse
Returns a list of running clusters in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
270 |
# File 'sig/client.rbs', line 270
def list_clusters: (
|
#list_compute_node_groups(params = {}) ⇒ Types::ListComputeNodeGroupsResponse
Returns a list of all compute node groups associated with a cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
282 |
# File 'sig/client.rbs', line 282
def list_compute_node_groups: (
|
#list_queues(params = {}) ⇒ Types::ListQueuesResponse
Returns a list of all queues associated with a cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
295 |
# File 'sig/client.rbs', line 295
def list_queues: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of all tags on an PCS resource.
307 |
# File 'sig/client.rbs', line 307
def list_tags_for_resource: (
|
#register_compute_node_group_instance(params = {}) ⇒ Types::RegisterComputeNodeGroupInstanceResponse
This API action isn't intended for you to use.
PCS uses this API action to register the compute nodes it launches in your account.
319 |
# File 'sig/client.rbs', line 319
def register_compute_node_group_instance: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or edits tags on an PCS resource. Each tag consists of a tag key and a tag value. The tag key and tag value are case-sensitive strings. The tag value can be an empty (null) string. To add a tag, specify a new tag key and a tag value. To edit a tag, specify an existing tag key and a new tag value.
329 |
# File 'sig/client.rbs', line 329
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Deletes tags from an PCS resource. To delete a tag, specify the tag key and the Amazon Resource Name (ARN) of the PCS resource.
339 |
# File 'sig/client.rbs', line 339
def untag_resource: (
|
#update_cluster(params = {}) ⇒ Types::UpdateClusterResponse
Updates a cluster configuration. You can upgrade the Slurm version, modify scheduler settings, and update accounting configuration for an existing cluster. For more information about upgrading the Slurm version, see Upgrading the Slurm version on a cluster in the PCS User Guide.
ACTIVE, UPDATE_FAILED, or
SUSPENDED state. All associated resources (queues and compute node
groups) must be in ACTIVE state before you can update the cluster.
350 |
# File 'sig/client.rbs', line 350
def update_cluster: (
|
#update_compute_node_group(params = {}) ⇒ Types::UpdateComputeNodeGroupResponse
Updates a compute node group. You can update many of the fields related to your compute node group including the configurations for networking, compute nodes, and settings specific to your scheduler (such as Slurm).
392 |
# File 'sig/client.rbs', line 392
def update_compute_node_group: (
|
#update_queue(params = {}) ⇒ Types::UpdateQueueResponse
Updates the compute node group configuration of a queue. Use this API to change the compute node groups that the queue can send jobs to.
428 |
# File 'sig/client.rbs', line 428
def update_queue: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1892 1893 1894 |
# File 'lib/aws-sdk-pcs/client.rb', line 1892 def waiter_names [] end |