Class: Aws::PCS::Types::ComputeNodeGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::ComputeNodeGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
A compute node group associated with a cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ami_id ⇒ String
The ID of the Amazon Machine Image (AMI) that PCS uses to launch instances.
-
#arn ⇒ String
The unique Amazon Resource Name (ARN) of the compute node group.
-
#cluster_id ⇒ String
The ID of the cluster of the compute node group.
-
#created_at ⇒ Time
The date and time the resource was created.
-
#custom_launch_template ⇒ Types::CustomLaunchTemplate
An Amazon EC2 launch template PCS uses to launch compute nodes.
-
#error_info ⇒ Array<Types::ErrorInfo>
The list of errors that occurred during compute node group provisioning.
-
#iam_instance_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM instance profile used to pass an IAM role when launching EC2 instances.
-
#id ⇒ String
The generated unique ID of the compute node group.
-
#instance_configs ⇒ Array<Types::InstanceConfig>
A list of EC2 instance configurations that PCS can provision in the compute node group.
-
#modified_at ⇒ Time
The date and time the resource was modified.
-
#name ⇒ String
The name that identifies the compute node group.
-
#purchase_option ⇒ String
Specifies how EC2 instances are purchased on your behalf.
-
#scaling_configuration ⇒ Types::ScalingConfiguration
Specifies the boundaries of the compute node group auto scaling.
-
#slurm_configuration ⇒ Types::ComputeNodeGroupSlurmConfiguration
Additional options related to the Slurm scheduler.
-
#spot_options ⇒ Types::SpotOptions
Additional configuration when you specify ‘SPOT` as the `purchaseOption` for the `CreateComputeNodeGroup` API action.
-
#status ⇒ String
The provisioning status of the compute node group.
-
#subnet_ids ⇒ Array<String>
The list of subnet IDs where instances are provisioned by the compute node group.
Instance Attribute Details
#ami_id ⇒ String
The ID of the Amazon Machine Image (AMI) that PCS uses to launch instances. If not provided, PCS uses the AMI ID specified in the custom launch template.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The unique Amazon Resource Name (ARN) of the compute node group.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#cluster_id ⇒ String
The ID of the cluster of the compute node group.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the resource was created.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#custom_launch_template ⇒ Types::CustomLaunchTemplate
An Amazon EC2 launch template PCS uses to launch compute nodes.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#error_info ⇒ Array<Types::ErrorInfo>
The list of errors that occurred during compute node group provisioning.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#iam_instance_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM instance profile used to pass an IAM role when launching EC2 instances. The role contained in your instance profile must have the ‘pcs:RegisterComputeNodeGroupInstance` permission and the role name must start with `AWSPCS` or must have the path `/aws-pcs/`. For more information, see [IAM instance profiles for PCS] in the *PCS User Guide*.
[1]: docs.aws.amazon.com/pcs/latest/userguide/security-instance-profiles.html
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The generated unique ID of the compute node group.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#instance_configs ⇒ Array<Types::InstanceConfig>
A list of EC2 instance configurations that PCS can provision in the compute node group.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time the resource was modified.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name that identifies the compute node group.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#purchase_option ⇒ String
Specifies how EC2 instances are purchased on your behalf. PCS supports On-Demand Instances, Spot Instances, Interruptible Capacity Reservations, On-Demand Capacity Reservations, and Amazon EC2 Capacity Blocks for ML. For more information, see [Amazon EC2 billing and purchasing options] in the *Amazon Elastic Compute Cloud User Guide*. For more information about PCS support for Capacity Blocks, see [Using Amazon EC2 Capacity Blocks for ML with PCS] in the *PCS User Guide*. For more information about PCS support for interruptible capacity reservations, see [Using I-ODCRs with PCS] in the *PCS User Guide*. Choose On-Demand if you plan to use an On-Demand Capacity Reservation (ODCR). For more information, see [Using ODCRs with PCS]. If you don’t provide this option, it defaults to On-Demand.
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-purchasing-options.html [2]: docs.aws.amazon.com/pcs/latest/userguide/capacity-blocks.html [3]: docs.aws.amazon.com/pcs/latest/userguide/capacity-reservations-iodcr.html [4]: docs.aws.amazon.com/pcs/latest/userguide/capacity-reservations-odcr.html
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#scaling_configuration ⇒ Types::ScalingConfiguration
Specifies the boundaries of the compute node group auto scaling.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#slurm_configuration ⇒ Types::ComputeNodeGroupSlurmConfiguration
Additional options related to the Slurm scheduler.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#spot_options ⇒ Types::SpotOptions
Additional configuration when you specify ‘SPOT` as the `purchaseOption` for the `CreateComputeNodeGroup` API action.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The provisioning status of the compute node group.
<note markdown=“1”> The provisioning status doesn’t indicate the overall health of the compute node group.
</note>
The resource enters the ‘SUSPENDING` and `SUSPENDED` states when the scheduler is beyond end of life and we have suspended the cluster. When in these states, you can’t use the cluster. The cluster controller is down and all compute instances are terminated. The resources still count toward your service quotas. You can delete a resource if its status is ‘SUSPENDED`. For more information, see
- Frequently asked questions about Slurm versions in PCS][1
-
in the
*PCS User Guide*.
[1]: docs.aws.amazon.com/pcs/latest/userguide/slurm-versions_faq.html
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The list of subnet IDs where instances are provisioned by the compute node group. The subnets must be in the same VPC as the cluster.
518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/aws-sdk-pcs/types.rb', line 518 class ComputeNodeGroup < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status, :ami_id, :subnet_ids, :purchase_option, :custom_launch_template, :iam_instance_profile_arn, :scaling_configuration, :instance_configs, :spot_options, :slurm_configuration, :error_info) SENSITIVE = [] include Aws::Structure end |