Class: Aws::PCS::Types::ListClustersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::ListClustersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results that are returned per call.
-
#next_token ⇒ String
The value of
nextTokenis a unique pagination token for each page of results returned.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results that are returned per call. You can
use nextToken to obtain further pages of results. The default is
10 results, and the maximum allowed page size is 100 results. A
value of 0 uses the default.
1349 1350 1351 1352 1353 1354 |
# File 'lib/aws-sdk-pcs/types.rb', line 1349 class ListClustersRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The value of nextToken is a unique pagination token for each page
of results returned. If nextToken is returned, there are more
results available. Make the call again using the returned token to
retrieve the next page. Keep all other arguments unchanged. Each
pagination token expires after 24 hours. Using an expired pagination
token returns an HTTP 400 InvalidToken error.
1349 1350 1351 1352 1353 1354 |
# File 'lib/aws-sdk-pcs/types.rb', line 1349 class ListClustersRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |