Class: Aws::PCS::Types::NodeLifecycleActions
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::NodeLifecycleActions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
The lifecycle actions configured on a compute node group. Lifecycle actions define scripts that PCS runs on compute nodes at specific stages of their lifecycle.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#script_caching_policy ⇒ String
The caching policy for node lifecycle scripts.
-
#stages ⇒ Types::NodeLifecycleStages
The lifecycle stages where you configure scripts to run.
Instance Attribute Details
#script_caching_policy ⇒ String
The caching policy for node lifecycle scripts. The default value is
CACHE_ONCE. Valid values:
-
CACHE_ONCE– Downloads each script once and reuses it on subsequent boots. -
REFRESH_ON_REBOOT– Downloads each script on every boot.
1600 1601 1602 1603 1604 1605 |
# File 'lib/aws-sdk-pcs/types.rb', line 1600 class NodeLifecycleActions < Struct.new( :stages, :script_caching_policy) SENSITIVE = [] include Aws::Structure end |
#stages ⇒ Types::NodeLifecycleStages
The lifecycle stages where you configure scripts to run.
1600 1601 1602 1603 1604 1605 |
# File 'lib/aws-sdk-pcs/types.rb', line 1600 class NodeLifecycleActions < Struct.new( :stages, :script_caching_policy) SENSITIVE = [] include Aws::Structure end |