Class: Aws::PCS::Types::Queue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

A queue resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The unique Amazon Resource Name (ARN) of the queue.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
# File 'lib/aws-sdk-pcs/types.rb', line 1609

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :slurm_configuration,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_idString

The ID of the cluster of the queue.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
# File 'lib/aws-sdk-pcs/types.rb', line 1609

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :slurm_configuration,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#compute_node_group_configurationsArray<Types::ComputeNodeGroupConfiguration>

The list of compute node group configurations associated with the queue. Queues assign jobs to associated compute node groups.



1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
# File 'lib/aws-sdk-pcs/types.rb', line 1609

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :slurm_configuration,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the resource was created.

Returns:

  • (Time)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
# File 'lib/aws-sdk-pcs/types.rb', line 1609

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :slurm_configuration,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#error_infoArray<Types::ErrorInfo>

The list of errors that occurred during queue provisioning.

Returns:



1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
# File 'lib/aws-sdk-pcs/types.rb', line 1609

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :slurm_configuration,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The generated unique ID of the queue.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
# File 'lib/aws-sdk-pcs/types.rb', line 1609

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :slurm_configuration,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime

The date and time the resource was modified.

Returns:

  • (Time)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
# File 'lib/aws-sdk-pcs/types.rb', line 1609

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :slurm_configuration,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name that identifies the queue.

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
# File 'lib/aws-sdk-pcs/types.rb', line 1609

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :slurm_configuration,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#slurm_configurationTypes::QueueSlurmConfiguration

Additional options related to the Slurm scheduler.



1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
# File 'lib/aws-sdk-pcs/types.rb', line 1609

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :slurm_configuration,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The provisioning status of the queue.

<note markdown=“1”> The provisioning status doesn’t indicate the overall health of the queue.

</note>

The resource enters the ‘SUSPENDING` and `SUSPENDED` states when the scheduler is beyond end of life and we have suspended the cluster. When in these states, you can’t use the cluster. The cluster controller is down and all compute instances are terminated. The resources still count toward your service quotas. You can delete a resource if its status is ‘SUSPENDED`. For more information, see

Frequently asked questions about Slurm versions in PCS][1

in the

*PCS User Guide*.

[1]: docs.aws.amazon.com/pcs/latest/userguide/slurm-versions_faq.html

Returns:

  • (String)


1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
# File 'lib/aws-sdk-pcs/types.rb', line 1609

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :slurm_configuration,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end