Class: Aws::PCS::Types::Queue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcs/types.rb

Overview

A queue resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The unique Amazon Resource Name (ARN) of the queue.

Returns:

  • (String)


1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
# File 'lib/aws-sdk-pcs/types.rb', line 1310

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_idString

The ID of the cluster of the queue.

Returns:

  • (String)


1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
# File 'lib/aws-sdk-pcs/types.rb', line 1310

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#compute_node_group_configurationsArray<Types::ComputeNodeGroupConfiguration>

The list of compute node group configurations associated with the queue. Queues assign jobs to associated compute node groups.



1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
# File 'lib/aws-sdk-pcs/types.rb', line 1310

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time the resource was created.

Returns:

  • (Time)


1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
# File 'lib/aws-sdk-pcs/types.rb', line 1310

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#error_infoArray<Types::ErrorInfo>

The list of errors that occurred during queue provisioning.

Returns:



1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
# File 'lib/aws-sdk-pcs/types.rb', line 1310

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The generated unique ID of the queue.

Returns:

  • (String)


1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
# File 'lib/aws-sdk-pcs/types.rb', line 1310

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime

The date and time the resource was modified.

Returns:

  • (Time)


1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
# File 'lib/aws-sdk-pcs/types.rb', line 1310

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name that identifies the queue.

Returns:

  • (String)


1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
# File 'lib/aws-sdk-pcs/types.rb', line 1310

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The provisioning status of the queue.

<note markdown=“1”> The provisioning status doesn’t indicate the overall health of the queue.

</note>

Returns:

  • (String)


1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
# File 'lib/aws-sdk-pcs/types.rb', line 1310

class Queue < Struct.new(
  :name,
  :id,
  :arn,
  :cluster_id,
  :created_at,
  :modified_at,
  :status,
  :compute_node_group_configurations,
  :error_info)
  SENSITIVE = []
  include Aws::Structure
end