Class: Aws::PCS::Types::QueueSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::QueueSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
The object returned by the ‘ListQueues` API action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The unique Amazon Resource Name (ARN) of the queue.
-
#cluster_id ⇒ String
The ID of the cluster of the queue.
-
#created_at ⇒ Time
The date and time the resource was created.
-
#id ⇒ String
The generated unique ID of the queue.
-
#modified_at ⇒ Time
The date and time the resource was modified.
-
#name ⇒ String
The name that identifies the queue.
-
#status ⇒ String
The provisioning status of the queue.
Instance Attribute Details
#arn ⇒ String
The unique Amazon Resource Name (ARN) of the queue.
1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'lib/aws-sdk-pcs/types.rb', line 1704 class QueueSummary < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status) SENSITIVE = [] include Aws::Structure end |
#cluster_id ⇒ String
The ID of the cluster of the queue.
1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'lib/aws-sdk-pcs/types.rb', line 1704 class QueueSummary < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time the resource was created.
1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'lib/aws-sdk-pcs/types.rb', line 1704 class QueueSummary < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The generated unique ID of the queue.
1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'lib/aws-sdk-pcs/types.rb', line 1704 class QueueSummary < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status) SENSITIVE = [] include Aws::Structure end |
#modified_at ⇒ Time
The date and time the resource was modified.
1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'lib/aws-sdk-pcs/types.rb', line 1704 class QueueSummary < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name that identifies the queue.
1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'lib/aws-sdk-pcs/types.rb', line 1704 class QueueSummary < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The provisioning status of the queue.
<note markdown=“1”> The provisioning status doesn’t indicate the overall health of the queue.
</note>
The resource enters the ‘SUSPENDING` and `SUSPENDED` states when the scheduler is beyond end of life and we have suspended the cluster. When in these states, you can’t use the cluster. The cluster controller is down and all compute instances are terminated. The resources still count toward your service quotas. You can delete a resource if its status is ‘SUSPENDED`. For more information, see
- Frequently asked questions about Slurm versions in PCS][1
-
in the
*PCS User Guide*.
[1]: docs.aws.amazon.com/pcs/latest/userguide/slurm-versions_faq.html
1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'lib/aws-sdk-pcs/types.rb', line 1704 class QueueSummary < Struct.new( :name, :id, :arn, :cluster_id, :created_at, :modified_at, :status) SENSITIVE = [] include Aws::Structure end |