Class: Aws::PCS::Types::Scheduler
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::Scheduler
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
The cluster management and job scheduling software associated with the cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#type ⇒ String
The software PCS uses to manage cluster scaling and job scheduling.
-
#version ⇒ String
The version of the specified scheduling software that PCS uses to manage cluster scaling and job scheduling.
Instance Attribute Details
#type ⇒ String
The software PCS uses to manage cluster scaling and job scheduling.
1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-pcs/types.rb', line 1868 class Scheduler < Struct.new( :type, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the specified scheduling software that PCS uses to
manage cluster scaling and job scheduling. You can upgrade this
version using the UpdateCluster API action. For more information,
see Upgrading the Slurm version on a cluster and Slurm
versions in PCS in the PCS User Guide.
Valid Values: 23.11 | 24.05 | 24.11 | 25.05 | 25.11
1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-pcs/types.rb', line 1868 class Scheduler < Struct.new( :type, :version) SENSITIVE = [] include Aws::Structure end |