Class: Aws::PCS::Types::ScriptSource
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::ScriptSource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
The source location and integrity information for a node lifecycle script.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checksum ⇒ String
The SHA-256 checksum of the script content, as a 64-character hexadecimal string.
-
#s3_version_id ⇒ String
The Amazon S3 version ID of the script.
-
#script_location ⇒ String
The location of the script.
Instance Attribute Details
#checksum ⇒ String
The SHA-256 checksum of the script content, as a 64-character hexadecimal string. This value is optional. When specified, PCS uses this value to verify the integrity of the downloaded script.
2100 2101 2102 2103 2104 2105 2106 |
# File 'lib/aws-sdk-pcs/types.rb', line 2100 class ScriptSource < Struct.new( :script_location, :s3_version_id, :checksum) SENSITIVE = [] include Aws::Structure end |
#s3_version_id ⇒ String
The Amazon S3 version ID of the script. Use this value to pin the
script to a specific version in a versioned Amazon S3 bucket. This
value is only valid when scriptLocation is an Amazon S3 URI.
2100 2101 2102 2103 2104 2105 2106 |
# File 'lib/aws-sdk-pcs/types.rb', line 2100 class ScriptSource < Struct.new( :script_location, :s3_version_id, :checksum) SENSITIVE = [] include Aws::Structure end |
#script_location ⇒ String
The location of the script. Specify either an Amazon S3 URI in the
format s3://bucket-name/key or an HTTPS URL.
2100 2101 2102 2103 2104 2105 2106 |
# File 'lib/aws-sdk-pcs/types.rb', line 2100 class ScriptSource < Struct.new( :script_location, :s3_version_id, :checksum) SENSITIVE = [] include Aws::Structure end |