Class: Aws::PCS::Types::SlurmCustomSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::SlurmCustomSetting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
Additional settings that directly map to Slurm settings.
PCS supports a subset of Slurm settings. For more information, see Configuring custom Slurm settings in PCS in the PCS User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#parameter_name ⇒ String
PCS supports custom Slurm settings for clusters, compute node groups, and queues.
-
#parameter_value ⇒ String
The values for the configured Slurm settings.
Instance Attribute Details
#parameter_name ⇒ String
PCS supports custom Slurm settings for clusters, compute node groups, and queues. For more information, see Configuring custom Slurm settings in PCS in the PCS User Guide.
2002 2003 2004 2005 2006 2007 |
# File 'lib/aws-sdk-pcs/types.rb', line 2002 class SlurmCustomSetting < Struct.new( :parameter_name, :parameter_value) SENSITIVE = [] include Aws::Structure end |
#parameter_value ⇒ String
The values for the configured Slurm settings.
2002 2003 2004 2005 2006 2007 |
# File 'lib/aws-sdk-pcs/types.rb', line 2002 class SlurmCustomSetting < Struct.new( :parameter_name, :parameter_value) SENSITIVE = [] include Aws::Structure end |