Class: Aws::PCS::Types::UpdateClusterRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PCS::Types::UpdateClusterRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pcs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cluster_identifier ⇒ String
The name or ID of the cluster to update.
-
#scheduler ⇒ Types::UpdateSchedulerRequest
The scheduler configuration to update for the cluster.
-
#slurm_configuration ⇒ Types::UpdateClusterSlurmConfigurationRequest
Additional options related to the Slurm scheduler.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don't specify a client token, the CLI and SDK automatically generate 1 for you.
A suitable default value is auto-generated. You should normally not need to pass this option.
2231 2232 2233 2234 2235 2236 2237 2238 |
# File 'lib/aws-sdk-pcs/types.rb', line 2231 class UpdateClusterRequest < Struct.new( :cluster_identifier, :client_token, :slurm_configuration, :scheduler) SENSITIVE = [] include Aws::Structure end |
#cluster_identifier ⇒ String
The name or ID of the cluster to update.
2231 2232 2233 2234 2235 2236 2237 2238 |
# File 'lib/aws-sdk-pcs/types.rb', line 2231 class UpdateClusterRequest < Struct.new( :cluster_identifier, :client_token, :slurm_configuration, :scheduler) SENSITIVE = [] include Aws::Structure end |
#scheduler ⇒ Types::UpdateSchedulerRequest
The scheduler configuration to update for the cluster. Use this to upgrade the Slurm version. For more information, see Upgrading the Slurm version on a cluster in the PCS User Guide.
2231 2232 2233 2234 2235 2236 2237 2238 |
# File 'lib/aws-sdk-pcs/types.rb', line 2231 class UpdateClusterRequest < Struct.new( :cluster_identifier, :client_token, :slurm_configuration, :scheduler) SENSITIVE = [] include Aws::Structure end |
#slurm_configuration ⇒ Types::UpdateClusterSlurmConfigurationRequest
Additional options related to the Slurm scheduler.
2231 2232 2233 2234 2235 2236 2237 2238 |
# File 'lib/aws-sdk-pcs/types.rb', line 2231 class UpdateClusterRequest < Struct.new( :cluster_identifier, :client_token, :slurm_configuration, :scheduler) SENSITIVE = [] include Aws::Structure end |